integrate_events

Function integrate_events 

pub fn integrate_events()
Enable the integration between GStreamer logging system and the tracing library.

Once enabled the default [tracing::Subscriber][tracing_core::subscriber::Subscriber] will receive an event for each of the GStreamer debug log messages.

The events produced this way will specify the “current” span as the event’s parent. Doing nothing else, there won’t be any span to act as the parent. Consider also using the integrations for producing spans.

This function can be executed at any time and will process events that occur after its execution.

Calling this function multiple times may cause duplicate events to be produced.