pub fn disable_events()Expand description
Disable the integration between GStreamer logging system and the tracing library.
As an implementation detail, this will not release certain resources that have been allocated
during the period of event integration. Some of the resources are required to live for
'static and therefore cannot be soundly released by any other way except by terminating the
program.