pub fn integrate_spans()Expand description
Enable the integration between GStreamer tracing system and the tracing library.
Once enabled the default [tracing::Subscriber][tracing_core::subscriber::Subscriber] will
have spans entered for certain GStreamer events such as data being pushed to a pad.
This will provide some meaningful context to the events produced by integrating those.
This function may only be called after gst::init.